@@ -1,12 +1,11 @@
 import inspect
 import logging
 
-from pkg_resources import iter_entry_points
-
 from connect.client import AsyncConnectClient, ConnectClient
 from connect.eaas.core.logging import ExtensionLogHandler, RequestLogger
 from connect.eaas.runner.config import ConfigHelper
 from connect.eaas.runner.constants import EVENT_TYPE_EXT_METHOD_MAP
+from connect.eaas.runner.helpers import iter_entry_points
 
 
 logger = logging.getLogger(__name__)
@@ -54,6 +53,13 @@ class EventsApp:
     def changelog(self):
         return self._descriptor['changelog_url']
 
+    @property
+    def features(self):
+        return {
+            'events': self.get_events(),
+            'schedulables': self.get_schedulables(),
+        }
+
     def get_method(
         self,
         event_type,
