@@ -4,10 +4,10 @@ import logging
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 from fastapi.staticfiles import StaticFiles
-from fastapi.openapi.utils import get_openapi
-from pkg_resources import iter_entry_points
+from fastapi.openapi.utils import generate_operation_summary, get_openapi
 
 from connect.eaas.runner.config import ConfigHelper
+from connect.eaas.runner.helpers import iter_entry_points
 
 
 logger = logging.getLogger(__name__)
@@ -54,7 +54,7 @@ class WebApp:
 
     @property
     def ui_modules(self):
-        return self._webapp_class.get_descriptor().get('ui', {})
+        return self._webapp_class.get_ui_modules()
 
     @property
     def variables(self):
@@ -78,6 +78,28 @@ class WebApp:
             self._app = self.get_asgi_application()
         return self._app
 
+    @property
+    def features(self):
+        return {
+            'endpoints': self.get_endpoints(),
+        }
+
+    def get_endpoints(self):
+        auth, no_auth = self._webapp_class.get_routers()
+        endpoints = {
+            'auth': [],
+            'no_auth': [],
+        }
+        for router, group in ((auth, 'auth'), (no_auth, 'no_auth')):
+            for route in router.routes:
+                for method in route.methods:
+                    endpoints[group].append({
+                        'summary': generate_operation_summary(route=route, method=method),
+                        'method': method,
+                        'path': route.path,
+                    })
+        return endpoints
+
     def get_asgi_application(self):
         app = FastAPI(
             openapi_url='/openapi/spec.json',
